.. _cli:

==================
Command Line Guide
==================

.. only:: html

    .. include:: introduction.rst
        :start-after: .. cli-start
        :end-before: .. cli-end

    .. rubric:: Guide Contents

.. toctree::
    :maxdepth: 3

    introduction
    <material> <material.rst>
    <domain> <domain.rst>
    <settings> <settings.rst>